# Contribution Guide

Contribution is welcome! There are many ways you could help Vetur's development:

- Triaging Issues
- Writing Code
- Improving Doc

For more information, please read: https://github.com/vuejs/vetur/wiki#contribution-guide.